<?php

switch ($messaggio) {

case "Vedi le prenotazioni":  			$messaggio = "Se reservationer"; break;
case "presenti dal":  				$messaggio = "fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "Senza colori":  				$messaggio = "Med f&auml;rger"; break;
case "Con colori":  				$messaggio = "Utan f&auml;rger"; break;
case "Tabella prenotazioni precedenti al":  	$messaggio = "Tabell med reservationer f&ouml;re"; break;
case "Tabella prenotazioni successive al":  	$messaggio = "Tabell med reservationer efter"; break;
case "Tabella con tutte le prenotazioni":  	$messaggio = "Tabell med alla reservationer"; break;
case "Cognome_cliente":  			$messaggio = "Kund_efternamn"; break;
case "Data_iniziale":  				$messaggio = "Startdatum"; break;
case "Data_finale":  				$messaggio = "Slutdatum"; break;
case "sett":  					$messaggio = "veckor"; break;
case "gio":  					$messaggio = "dagar"; break;
case "Tariffa_completa":  			$messaggio = "Komplett_pris"; break;
case "Caparra":  				$messaggio = "Deposition"; break;
case "Pagato":  				$messaggio = "Betalad"; break;
case "Da_pagare":  				$messaggio = "Att_betala"; break;
case "Pers.":  					$messaggio = "Pers."; break;
case "Commento":  				$messaggio = "Kommentar"; break;
case "Costo_uni.":  				$messaggio = "Engangskostnad"; break;
case "Costo_sett.":  				$messaggio = "Veckokostnad"; break;
case "Costo_gio.":  				$messaggio = "Dagskostnad"; break;
case "Soldi di prenotazioni cancellate":  	$messaggio = "Pengar f&ouml;r borttagna reservationer"; break;
case "TOTALE":  				$messaggio = "TOTALT"; break;
case "Trasferito in cassa":  			$messaggio = "&Ouml;verf&ouml;rt i kontanter"; break;
case "RESTO":  					$messaggio = "RESTERANDE"; break;
case "Sei sicuro di voler cancellare la spesa":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill ta bort den kontanta betalningen"; break;
case "del valore di":  				$messaggio = "fr&aring;n"; break;
case "Sei sicuro di voler cancellare l'entrata":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill ta bort det kontanta kvittot"; break;
case "SI":  					$messaggio = "JA"; break;
case "NO":  					$messaggio = "NEJ"; break;
case "Entrata o spesa":  			$messaggio = "Kontant betalning eller kvitto"; break;
case "cacellata":  				$messaggio = "borttagen"; break;
case "Costo o spesa già cancellati":  		$messaggio = "Kontant betalning eller kvitto har redan tagits bort"; break;
case "Natura_spesa":  				$messaggio = "Betalningsanledning"; break;
case "Importo":  				$messaggio = "Varde"; break;
case "Inserita_da":  				$messaggio = "Infogad_av"; break;
case "Data_di_inserimento":  			$messaggio = "Infogningsdatum"; break;
case "Cancella":  				$messaggio = "Ta bort"; break;
case "Natura_entrata":  			$messaggio = "Kvittoanledning"; break;
case "cancella":  				$messaggio = "ta bort"; break;
case "entrata presa dalle prenotazioni":  	$messaggio = "Kontant kvitto taget f&ouml;r reservationer"; break;
case "Inserisci nuove spese o entrate":  	$messaggio = "L&auml;gg till ny kontant kvitto eller betalning"; break;
case "Storia entrate-uscite prenotazioni":  	$messaggio = "Historik f&ouml;r betalda reservationer"; break;
case "Sei sicuro di voler cancellare il costo aggiuntivo":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill ta bort extrakostnad"; break;
case "Il costo aggiuntivo":  			$messaggio = "Extrakostnaden"; break;
case "Il costo aggiuntivo è cambiato nel frattempo, non è stato cancellato":	$messaggio = "Extrakostnaden &auml;ndrades men har inte tagits bort"; break;
case "è stato cancellato":  			$messaggio = "har tagits bort"; break;
case "I periodi sono stati aggiunti fino al":  	$messaggio = "Perioder har lagts till tills"; break;
case "Tabella con periodi e relative tariffe del":	$messaggio = "Tabell med perioder och tillh&ouml;rande priser f&ouml;r"; break;
case "tariffa":  				$messaggio = "pris"; break;
case "Inizio_settimana":  			$messaggio = "Startvecka"; break;
case "Inizio_giorno":  				$messaggio = "Startdag"; break;
case "Fine_settimana":  			$messaggio = "Slutvecka"; break;
case "Fine_giorno":  				$messaggio = "Slutdag"; break;
case "Aggiungi periodi":  			$messaggio = "L&auml;gg till perioder"; break;
case "fino al mese":  				$messaggio = "tills"; break;
case "Tabella con i costi aggiuntivi del":  	$messaggio = "Tabell med extrakostnader f&ouml;r"; break;
case "Nome":  					$messaggio = "Namn"; break;
case "Tipo":  					$messaggio = "Typ"; break;
case "Prezzo":  				$messaggio = "Varde"; break;
case "Da_assegnare":  				$messaggio = "Att_overlata"; break;
case "finale":  				$messaggio = "enkel"; break;
case "Sempre":  				$messaggio = "Alltid"; break;
case "Su_richiesta":  				$messaggio = "Vid_forfragan"; break;
case "chidere_per_quanto_moltiplicare":  	$messaggio = "fraga_med_hur_mycket_det_ska_multipliceras"; break;
case "cosiderare_come_letti_aggiuntivi":  	$messaggio = "se_som_extrabaddar"; break;
case "settimanale":  				$messaggio = "veckovis"; break;
case "giornaliero":  				$messaggio = "dagligen"; break;
case "tutte":  				$messaggio = "alla"; break;
case "tutti":  				$messaggio = "alla"; break;
case "_le":  					$messaggio = ""; break;
case "_i":  					$messaggio = ""; break;
case "_settimane":  				$messaggio = "_veckor"; break;
case "_giorni":  				$messaggio = "_dagar"; break;
case "_meno_una":  				$messaggio = "_minus_en"; break;
case "con_n°_di_settimane":  			$messaggio = "fraga_om_antal_veckor"; break;
case "con_n°_di_giorni":  			$messaggio = "fraga_om_antal_dagar"; break;
case "_da_chiedere":  				$messaggio = ""; break;
case "percentuale":  				$messaggio = "procentandel"; break;
case "% arrotondato_a_":  			$messaggio = "% avrundas_till_"; break;
case "Vai alla pagina di inserzione prezzi":  	$messaggio = "Till sidan f&ouml;r att l&auml;gga till priser"; break;
case "chiamati":  				$messaggio = "kallad"; break;
case "Cerca i clienti con cognome o email":  	$messaggio = "S&ouml;k kunder efter efeternamn eller e-post"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Tabell med alla kunder"; break;
case "pag. prec.":  				$messaggio = "f&ouml;reg&aring;ende sida"; break;
case "pag. succ.":  				$messaggio = "n&auml;sta sida"; break;
case "Cognome":  				$messaggio = "Efternamn"; break;
case "Nome":  					$messaggio = "Namn"; break;
case "Telefono":  				$messaggio = "Telefon"; break;
case "Indirizzo":  				$messaggio = "Adress"; break;
case "Città":  					$messaggio = "Stad"; break;
case "Nazione":  				$messaggio = "Land"; break;
case "CAP":  					$messaggio = "Postnummer"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Email":  					$messaggio = "E-post"; break;
case "Data_di_nascita":  			$messaggio = "F&ouml;delsedag"; break;
case "2°telefono":  				$messaggio = "Andra telefon"; break;
case "Commento":  				$messaggio = "Kommentar"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <b>ta bort </b> &ouml;verl&aring;tningsregel 2 f&ouml;r"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <b>ta bort</b> &ouml;verl&aring;tningsregel 3 f&ouml;r"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <b>ta bort</b> &ouml;verl&aring;telseregel 4 f&ouml;r"; break;
case "La regola di assegnazione è stata cancellata":	$messaggio = "&Ouml;verl&aring;tningsregeln har tagits bort"; break;
case "La regola di assegnazione è già stata cancellata":	$messaggio = "&Ouml;verl&aring;tningsregeln har redan tagits bort"; break;
case "Tabella con le regole di assegnazione 1 del":	$messaggio = "Tabell med &ouml;verl&aring;tningsregel 1 av"; break;
case "Motivazione":  				$messaggio = "Motivering"; break;
case "Tabella con le regole di assegnazione 2 del":	$messaggio = "Tabell med &ouml;verl&aring;tningsregel 2 av"; break;
case "Tariffa":  				$messaggio = "Pris"; break;
case "Inserisci nuove regole":  		$messaggio = "L&auml;gg till nya regler"; break;
case "Il numero inserito esiste già":  		$messaggio = "Det angivna numret finns redan"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Casa":  					$messaggio = "Hus"; break;
case "Piano":  					$messaggio = "V&aring;ning"; break;
case "Capienza_massima":  			$messaggio = "Max_kapacitet"; break;
case "Priorità":  				$messaggio = "Prioritet"; break;
case "Modifica":  				$messaggio = "&Auml;ndra"; break;
case "modifica":  				$messaggio = "&auml;ndra"; break;
case "Torna al menù principale":  		$messaggio = "Tillbaks till huvudmenyn"; break;
case "persone":  				$messaggio = "personer"; break;
case "s":  					$messaggio = "vecka"; break;
case "g":  					$messaggio = "dag"; break;
case "Mostra":  				$messaggio = "Visa"; break;
case "Non_mostrare":  				$messaggio = "Visa_inte"; break;
case "Regole":  				$messaggio = "Regler"; break;
case "Tariffe abbinate":  			$messaggio = "Tillh&ouml;rande priser"; break;
case "pagine":  				$messaggio = "sidor"; break;
case "Verranno effettuati i seguenti cambiamenti":	$messaggio = "F&ouml;ljande f&ouml;r&auml;ndringar kommer g&ouml;ras"; break;
case "I soldi pagati per la prenotazione":  	$messaggio = "Betalt f&ouml;r reservationen"; break;
case "a nome di":  				$messaggio = "f&ouml;r herr/fru"; break;
case "verranno cambiati da":  			$messaggio = "kommer &auml;ndras fr&aring;n"; break;
case "a":  					$messaggio = "till"; break;
case "saldo":  					$messaggio = "skillnad"; break;
case "Le prenotazioni <b>non sono state modificate</b> perchè sono cambiate nel frattempo":	$messaggio = "Reservationerna <b>har inte &auml;ndrats</b> eftersom reservationstabellen &auml;ndrades under tiden"; break;
case "tutto pagato":  				$messaggio = "alla betalda"; break;
case "caparra pagata":  			$messaggio = "deposition betald"; break;
case "pagato niente":  				$messaggio = "ingenting betalt"; break;
case "pagina":  				$messaggio = "sida"; break;
case "di":  					$messaggio = "av"; break;
case "la conferma":  				$messaggio = "bekr&auml;ftad"; break;
case "La prenotazione":  			$messaggio = "Reservationen"; break;
case "verrà confermata":  			$messaggio = "kommer bekr&auml;ftas"; break;
case "Data di inserimento":  			$messaggio = "Infogningsdatum"; break;
case "Calcola il subtotale delle prenotazioni selezionate":	$messaggio = "Ber&auml;kna delsumma f&ouml;r valda reservationer"; break;
case "selezionate precedentemente":  		$messaggio = "tidigare valda"; break;
case "Saldo totale":  				$messaggio = "Total skillnad"; break;
case "l'anno":  				$messaggio = "&aring;r"; break;
case "dal database":  				$messaggio = "fr&aring;n databasen"; break;
case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, tutti i dati riguardanti l'anno":	$messaggio = "<b style=\"color: red;\">VARNING</b>: om du trycker p&aring; <b>\"<i>Forts&auml;tt</i>\"</b> kommer alla data f&ouml;r &aring;r"; break;
case "verranno <b>cancellati</b>":  		$messaggio = "<b>tas bort</b>"; break;
case "L'anno":  				$messaggio = "&Aring;r"; break;
case "è stato cancellato dal batabase":  	$messaggio = "har tagits bort fr&aring;n databasen"; break;
case "Non è stato possibile cancellare l'anno":	$messaggio = "Det har inte g&aring;tt att ta bort &aring;r"; break;
case "dal database, controllare i permessi sulla cartella dati":	$messaggio = "fr&aring;n databasen, kolla beh&ouml;righeten till dati-mappen"; break;
case "Profilo":  				$messaggio = "Profil"; break;
case "Cliente":  				$messaggio = "Kund"; break;
case "cliente":  				$messaggio = "kund"; break;
case "Tabella con le regole di assegnazione 3 del":	$messaggio = "Tabell med &ouml;verl&aring;tningsregel 3 av"; break;
case "Utente":  				$messaggio = "Anv&auml;ndare"; break;
case "Periodi_permessi":  			$messaggio = "Tillatna_perioder"; break;
case "unico":  					$messaggio = "enkel"; break;
case "fisso":  					$messaggio = "fast"; break;
case "percentuale su tariffa":  		$messaggio = "procentandel av pris"; break;
case "percentuale su totale":  			$messaggio = "procentavdel av totalen"; break;
case "varia_con_la_prenotazione":  		$messaggio = "andras_med_reservationen"; break;
case "non_varia_con_la_prenotazione":  		$messaggio = "andras_inte_med_reservationen"; break;
case "_meno_l'ultima":  			$messaggio = "_utom_sista"; break;
case "_meno_l'ultimo":  			$messaggio = "_utom_sista"; break;
case "_meno_la_prima":  			$messaggio = "_utom_forsta"; break;
case "_meno_il_primo":  			$messaggio = "_utom_forsta"; break;
case "giorni":  				$messaggio = "dagarna"; break;
case "moltiplicare_per_persone":  		$messaggio = "multiplicera_med_antal_personer"; break;
case "moltiplicare_per_persone_totali":  	$messaggio = "multiplicera_med_totalt_antal_personer"; break;
case "moltiplicare_per_1":  			$messaggio = "multiplicera_med_1"; break;
case "massimo_":  				$messaggio = "maximalt_"; break;
case "_nella_stessa_settimana":  		$messaggio = "_samma_vecka"; break;
case "_nello_stesso_giorno":  			$messaggio = "_samma_dag"; break;
case "Prenotazione intera in":  		$messaggio = "Hela reservationen p&aring;"; break;
case "Parte della prentoazione in":  		$messaggio = "Del av reservationen p&aring;"; break;
case "Solo settimane della prenotazione in":  	$messaggio = "Endast veckor av bokning p&aring;"; break;
case "Solo giorni della prenotazione in":  	$messaggio = "Endast dagar av bokning p&aring;"; break;
case " o ":  					$messaggio = " eller "; break;
case " a ":  					$messaggio = " till "; break;
case "_si":  					$messaggio = "_ja"; break;
case "_no":  					$messaggio = "_nej"; break;
case "_e_":  					$messaggio = "_och_"; break;
case "associato_a_settimane_specifiche":  	$messaggio = "associerade_till_specifika_veckor"; break;
case "non_associato_a_settimane_specifiche":  	$messaggio = "inte_associerade_till_specifika_veckor"; break;
case "associato_a_giorni_specifici":  		$messaggio = "associerade_till_specifika_dagar"; break;
case "non_associato_a_giorni_specifici":  	$messaggio = "inte_associerade_till_specifika_dagar"; break;
case "modifica con prenotazione":  		$messaggio = "&auml;ndra med reservation"; break;
case "percentuale su caparra":  		$messaggio = "procentandel av deposition"; break;
case "percentuale su resto caparra":  		$messaggio = "procentandel av depositionsdifferens"; break;
case "Cancellati":  				$messaggio = "Borttagen"; break;
case "clienti":  				$messaggio = "kunder"; break;
case "OK":  					$messaggio = "OK"; break;
case "Annulla":  				$messaggio = "Avbryt"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>cancellare":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <div style=\"display: inline; color: red;\"><b>ta bort"; break;
case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun pagamento":	$messaggio = "kunder</b></div> som inte har n&aring;gon associerad reservation eller betalning"; break;
case "Cancella i clienti senza prenotazioni":	$messaggio = "Ta bort kunder utan reservationer"; break;
case "Metodo pagamento":  			$messaggio = "Betalningsmetod"; break;
case "Tariffe":  				$messaggio = "Priser"; break;
case "del":  					$messaggio = "f&ouml;r"; break;
case "Modifica tutti i campi della tabella":  	$messaggio = "&Auml;ndra alla tabellf&auml;lt"; break;
case "Modifica i campi della tabella":  	$messaggio = "&Auml;ndra tabellf&auml;lt"; break;
case "Applica i cambiamenti":  			$messaggio = "Till&auml;mpa &auml;ndringar"; break;
case "Vedi tutte le prenotazioni":  		$messaggio = "Se alla reservationer"; break;
case "Tabella con le regole di assegnazione 4 del":	$messaggio = "Tabell f&ouml;r &ouml;verl&aring;telseregel 4 av"; break;
case "Numero di persone":  			$messaggio = "Antal personder"; break;
case "assegna_se_":  				$messaggio = "overlat_om_"; break;
case "più_di_":  				$messaggio = "mindre_an_"; break;
case "meno_di_":  				$messaggio = "mer_an_"; break;
case "_giorni_da_inizio":  			$messaggio = "_dagar_fran_borjan"; break;
case "assegna_con_":  				$messaggio = "overlat_med_"; break;
case "_o_più_prenotazioni":  			$messaggio = "_eller_fler_reservationer"; break;
case "Modifica i prezzi":  			$messaggio = "&Auml;ndra priser"; break;
case "<div style=\"display: inline; color: red;\">Non</div> è stato possibile inserire alcuni prezzi":	$messaggio = "Det var <div style=\"display: inline; color: red;\">inte</div> m&ouml;jligt att infoga vissa priser"; break;
case "I prezzi sono stati aggiornati":  	$messaggio = "Priserna har uppdaterats"; break;
case "Tutte le prenotazioni":  			$messaggio = "Alla reservationer"; break;
case "Solo arrivi":  				$messaggio = "Endast ankomster"; break;
case "Solo partenze":  				$messaggio = "Endast avresor"; break;
case "dal":  					$messaggio = "fr&aring;n"; break;
case "Vedi":  					$messaggio = "Se"; break;
case "Tabella con tutti gli arrivi":  		$messaggio = "Tabell med alla ankomster"; break;
case "Tabella con tutte le partenze":  		$messaggio = "Tabell med alla avresor"; break;
case "prova ad importare i prezzi":  		$messaggio = "f&ouml;rs&ouml;k importera priser"; break;
case "giornalmente":  				$messaggio = "dagligen"; break;
case "settimanalmente":  			$messaggio = "veckovis"; break;
case "Origine":  				$messaggio = "Ursprung"; break;
case "Modifica come gruppo le prenotazioni mostrate in tabella":	$messaggio = "&Auml;ndra reservationer som visas i tabellen som en grupp"; break;
case "Statistiche":  				$messaggio = "Statistik"; break;
case "Anni":  					$messaggio = "&Aring;r"; break;
case "Numero di prenotazioni per mese":  	$messaggio = "Antal reservationer per m&aring;nad"; break;
case "Entrate dalle prenotazioni per mese":  	$messaggio = "Inkomster fr&aring;n reservationer per m&aring;nad"; break;
case "Entrate progressive dalle prenotazioni":	$messaggio = "Progressiva inkomster fr&aring;n reservationer"; break;
case "Numero di prenotazioni per origine":  	$messaggio = "Antal reservationer per ursprung"; break;
case "Entrate dalle prenotazioni per origine":	$messaggio = "Inkomster per ursprung"; break;
case "Cambia":  				$messaggio = "&Auml;ndra"; break;
case "Mesi":  					$messaggio = "M&aring;nader"; break;
case "Entrate per metodo di pagamento":  	$messaggio = "Inkomster per betalningsmetod"; break;
case "Descrizione":  				$messaggio = "Beskrivning"; break;
case "magazzino":  				$messaggio = "f&ouml;rvaringsrum"; break;
case "inventario":  				$messaggio = "inventarium"; break;
case "aggiungi":  				$messaggio = "l&auml;gg till"; break;
case "Codice":  				$messaggio = "Kod"; break;
case "Beni inventario":  			$messaggio = "Inventorieposter"; break;
case "Mancanti":  				$messaggio = "Saknas"; break;
case "bene eliminato":  			$messaggio = "post borttagen"; break;
case "bene aggiunto":  				$messaggio = "post tillagd"; break;
case "magazzino eliminato":  			$messaggio = "f&ouml;rvaringsrum borttaget"; break;
case "magazzino aggiunto":  			$messaggio = "f&ouml;rvaringsrum tillagt"; break;
case "Inventario importato":  			$messaggio = "Inventarium importerat"; break;
case "Importa l'invetario":  			$messaggio = "Importera inventarium"; break;
case "dal magazzino":  				$messaggio = "fr&aring;n f&ouml;rvaringsrum"; break;
case "Incompatibilità":  			$messaggio = "Inkompatibiliteter"; break;
case "raggruppa":  				$messaggio = "grupp"; break;
case "con email":  				$messaggio = "med e-post"; break;
case "in":  					$messaggio = "in"; break;
case "giorno":  				$messaggio = "day"; break;
case "p":  					$messaggio = "p"; break;
case "Aggiungi":  				$messaggio = "Add"; break;
case "Tutte le spese del":  			$messaggio = "All expenses of"; break;
case "nella cassa principale":  		$messaggio = "in main cashbox"; break;
case "Tutte le entrate del":  			$messaggio = "All incomes of"; break;
case "Caparre, commissioni e tasse del":  	$messaggio = "Deposits, commissions and taxes of"; break;
case "Arrotondato_a":  				$messaggio = "Rounded_to"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 1 for"; break;
case "porre per le prenotazioni selezionate":  	$messaggio = "selected reservations to"; break;
case "cambia":  				$messaggio = "change"; break;
case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "credit cards</b></div> from clients without reservations in the future and without unpaid reservations"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "Modifica come gruppo le prenotazioni selezionate":	$messaggio = "Modify selected reservations as a group"; break;
case "Importa":  				$messaggio = "Import"; break;
case "per persona":  				$messaggio = "per person"; break;
case "con meno di":  				$messaggio = "with less than"; break;
case "dall'inizio":  				$messaggio = "from beginning"; break;
case "dalla fine":  				$messaggio = "from ending"; break;
case "Mostra solo tariffe selezionate":  	$messaggio = "Show only selected rates"; break;
case "mostra prezzi settimanali":  		$messaggio = "show weekly prices"; break;
case "mostra prezzi giornalieri":  		$messaggio = "show daily prices"; break;
case "periodi di":  				$messaggio = "periods of"; break;
case "Valore":  				$messaggio = "Value"; break;
case "della tariffa":  				$messaggio = "of rate"; break;
case "piano":  					$messaggio = "floor"; break;
case "casa":  					$messaggio = "house"; break;
case "documento":  				$messaggio = "document"; break;
case "documenti salvati":  			$messaggio = "saved documents"; break;
case "numero":  				$messaggio = "number"; break;
case "nome file":  				$messaggio = "filename"; break;
case "prenotazioni":  				$messaggio = "reservations"; break;
case "azione":  				$messaggio = "action"; break;
case "anno":  					$messaggio = "year"; break;
case "elimina":  				$messaggio = "delete"; break;
case "fai l'upload del documento numero":  	$messaggio = "upload document number"; break;
case "fai l'upload":  				$messaggio = "upload"; break;
case "si è sicuri di voler <b class=\"colred\">cancellare</b> il documento":	$messaggio = "Are you sure you want to <b class=\"colred\">delete</b> document"; break;
case "cancellato":  				$messaggio = "deleted"; break;
case "inviato":  				$messaggio = "uploaded"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Tasse":  					$messaggio = "Taxes"; break;
case "senza_commissioni":  			$messaggio = "without_commissions"; break;
case "Documenti_salvati":  			$messaggio = "Saved_documents"; break;
case "TASSE":  					$messaggio = "TAXES"; break;
case "resto":  					$messaggio = "rest"; break;
case "cancella_periodi":  			$messaggio = "delete_periods"; break;
case "Sei sicuro di voler cancellare le commissioni dal":	$messaggio = "Are you sure you want to delete commissions from"; break;
case "sulla tariffa":  				$messaggio = "on rate"; break;
case "Le commissioni sono state cancellate":  	$messaggio = "Commissions have been deleted"; break;
case "Le commissioni sono cambiate nel frattempo, non sono state cancellate":	$messaggio = "Commissions have changed meanwhile, they have not been deleted"; break;
case "settimana":  				$messaggio = "week"; break;
case "costi agg.":  				$messaggio = "extra costs"; break;
case "sconto":  				$messaggio = "discount"; break;
case "Numero di prenotazioni per nazionalità del cliente titolare":	$messaggio = "Number of reservations per nationality of titular client"; break;
case "Entrate dalle prenotazioni per nazionalità del cliente titolare":	$messaggio = "Incomes from reservations per nationality of titular client"; break;
case "Prezzi con":  				$messaggio = "Prices with"; break;
case "Prenotazioni anno corrente":  		$messaggio = "Current year reservations"; break;
case "con prenotazioni inserite":  		$messaggio = "with reservations inserted"; break;
case "fino al":  				$messaggio = "until"; break;
case "nella cassa chiamata":  			$messaggio = "in the cashbox called"; break;
case "Totale nella cassa principale":  		$messaggio = "Total in main cashbox"; break;
case "Totale nella cassa":  			$messaggio = "Total in cashbox"; break;
case "Nuova cassa chiamata":  			$messaggio = "New cashbox called"; break;
case "Crea":  					$messaggio = "Create it"; break;
case "Una cassa chiamata":  			$messaggio = "A cashbox called"; break;
case "è stata creata":  			$messaggio = "has been created"; break;
case "Cassa chiamata":  			$messaggio = "Cashbox called"; break;
case "La cassa chiamata":  			$messaggio = "The cashbox called"; break;
case "è stata cancellata":  			$messaggio = "has been deleted"; break;
case "Eventuali entrate e spese presenti in cassa non sono state cancellate":	$messaggio = "Any incomes and expenses present in this cashbox have not been deleted"; break;
case "Modifica i beni già inseriti":  		$messaggio = "Modify already inserted items"; break;
case "Modifica i beni":  			$messaggio = "Modify items"; break;
case "I beni sono stati modificati":  		$messaggio = "The items have been modified"; break;
case "e combina":  				$messaggio = "and combine"; break;
case "percentuale su fisso della tariffa":	$messaggio = "percentage of fixed rate"; break;
case "percentuale su una persona della tariffa":	$messaggio = "percentage of one person of the rate"; break;
case "non più di":  				$messaggio = "no more than"; break;
case "non più del numero di persone":  		$messaggio = "no more than the number of people"; break;
case "non più del numero totale di persone":  	$messaggio = "no more than the total number of people"; break;
case "meno":  					$messaggio = "minus"; break;
case "aggiungendo":  				$messaggio = "adding"; break;
case "più di":  				$messaggio = "more than"; break;
case "prezzi importati":  			$messaggio = "prices imported"; break;
case "dalla tariffa":  				$messaggio = "from rate"; break;
case "Cancella le carte di credito di prenotazioni passate":	$messaggio = "Delete credit cards of past reservations"; break;
case "password per le carte di credito":  	$messaggio = "password for credit cards"; break;
case "Cancellate":  				$messaggio = "Deleted"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "Creare":  				$messaggio = "Create"; break;
case "persona":  				$messaggio = "person"; break;
case "chiusa":  				$messaggio = "closed"; break;
case "presenti in data":  			$messaggio = "present on"; break;
case "comprese partenze":  			$messaggio = "including departures"; break;
case "escludere_da_totale_percentuale":  	$messaggio = "exclude_from_percentage_total"; break;
case "da varie tariffe":  			$messaggio = "from different<br>rates"; break;
case "senza letti aggiuntivi":  		$messaggio = "without extra beds"; break;
case "Premere per modificare":  		$messaggio = "Click to modify"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>